==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=cs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Obnovit databázi',

	// I
	'info_restauration_sauvegarde' => 'obnova uložení @archive@', # MODIF
	'info_sauvegarde' => 'Uložení',
	'info_sauvegarde_reussi_02' => 'Databáze byla uložena do @archive@. Můžete',
	'info_sauvegarde_reussi_03' => 'se vrátit ke správě',
	'info_sauvegarde_reussi_04' => 'vašeho webu.',

	// T
	'texte_admin_tech_01' => 'Tato volba je určena k uložení obsahu databáze do souboru, jenž bude uložen v adresáři @dossier@. Nezapomeňte zálohovat i obsah celého adresáře @img@, ve kterém jsou uloženy obrázky a dokumenty použité v článcích a sekcích.',
	'texte_admin_tech_02' => 'Pozor! Takto uložené soubory lze obnovit POUZE na webu, kde je nainstalována stejná verze systému SPIP. V žádném případě "nevyprázdňujte databázi" s tím, že obnovíte zálohu po aktualizaci... Viz <a href="@spipnet@">la dokumentace k systému SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Obnovit obsah ze zálohy databáze',
	'texte_restaurer_sauvegarde' => 'Tato volba slouží k obnově dříve pořízené zálohy databáze.
  Záložní soubor musí být v adresáři @dossier@.
  Při použití této funkce postupujte opatrně. <b>Změny i případné ztráty
  jsou totiž nevratné.</b>', # MODIF
	'texte_sauvegarde' => 'Zálohovat obsah databáze',
	'texte_sauvegarde_base' => 'Uložit databázi'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=cs
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Obnovit databázi',

	// I
	'info_restauration_sauvegarde' => 'obnova uložení @archive@', # MODIF
	'info_sauvegarde' => 'Uložení',
	'info_sauvegarde_reussi_02' => 'Databáze byla uložena do @archive@. Můžete',
	'info_sauvegarde_reussi_03' => 'se vrátit ke správě',
	'info_sauvegarde_reussi_04' => 'vašeho webu.',

	// T
	'texte_admin_tech_01' => 'Tato volba je určena k uložení obsahu databáze do souboru, jenž bude uložen v adresáři @dossier@. Nezapomeňte zálohovat i obsah celého adresáře @img@, ve kterém jsou uloženy obrázky a dokumenty použité v článcích a sekcích.',
	'texte_admin_tech_02' => 'Pozor! Takto uložené soubory lze obnovit POUZE na webu, kde je nainstalována stejná verze systému SPIP. V žádném případě "nevyprázdňujte databázi" s tím, že obnovíte zálohu po aktualizaci... Viz <a href="@spipnet@">la dokumentace k systému SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Obnovit obsah ze zálohy databáze',
	'texte_restaurer_sauvegarde' => 'Tato volba slouží k obnově dříve pořízené zálohy databáze.
  Záložní soubor musí být v adresáři @dossier@.
  Při použití této funkce postupujte opatrně. <b>Změny i případné ztráty
  jsou totiž nevratné.</b>', # MODIF
	'texte_sauvegarde' => 'Zálohovat obsah databáze',
	'texte_sauvegarde_base' => 'Uložit databázi',
];
